# Código de Conduta do AgentFlowCraft

## 📜 Compromisso

Como participantes, colaboradores e mantenedores deste projeto, nós nos comprometemos a tornar a participação uma experiência respeitosa, acolhedora e livre de assédio para todos, independentemente de idade, tamanho corporal, deficiência, etnia, identidade e expressão de gênero, nível de experiência, nacionalidade, aparência pessoal, raça, religião ou identidade sexual.

## 🤝 Nossos padrões

Exemplos de comportamento que contribuem para criar um ambiente positivo incluem:

- Uso de linguagem acolhedora e inclusiva.
- Respeito a diferentes pontos de vista e experiências.
- Aceitação construtiva de críticas.
- Foco no que é melhor para a comunidade.
- Demonstração de empatia com outros membros.

Comportamentos inaceitáveis incluem:

- Uso de linguagem ou imagens sexualizadas e avanços sexuais indesejados.
- Comentários ofensivos ou depreciativos, ataques pessoais ou políticos.
- Assédio público ou privado.
- Divulgação de informações privadas de outras pessoas sem permissão explícita.
- Qualquer outro comportamento considerado inadequado em um ambiente profissional.

## 👮‍♀️ Responsabilidades dos mantenedores

Os mantenedores do projeto são responsáveis por esclarecer os padrões de comportamento aceitáveis e têm o direito de remover, editar ou rejeitar comentários, commits, código, edições de wiki, issues e outras contribuições que não estejam alinhadas com este Código de Conduta, bem como banir temporariamente ou permanentemente qualquer colaborador por comportamentos que julguem inadequados, ameaçadores, ofensivos ou prejudiciais.

## 🚨 Aplicação

Casos de comportamento abusivo, de assédio ou inaceitável podem ser reportados diretamente aos mantenedores do projeto. Todas as denúncias serão investigadas com responsabilidade e confidencialidade.

## 📬 Contato

Para dúvidas ou denúncias, envie um e-mail para **contato@agentflowcraft.dev** (endereço a ser confirmado).

## 🙌 Obrigado por ajudar a manter este ambiente acolhedor, colaborativo e respeitoso!
